@@ -1,12 +1,10 @@
 from teocomp.dfa import DFA
 from graphviz import Digraph
 from time import sleep
-from graphviz import Digraph
-from time import sleep
 import ipywidgets as widgets
 from IPython.display import clear_output
 import pandas as pd
-from IPython.display import display, Markdown
+from IPython.display import display
 from teocomp.bcolors import bcolors
 
 class NFA_E: # Non-Deterministic Finete Automata with Epsilon Transitions
