@@ -1,8 +1,3 @@
-import pandas as pd
-from IPython.display import HTML
-from IPython.display import display
-import pandas as pd
-from teocomp.bcolors import bcolors
 from teocomp.pcp import PCP
 
 PCPM_1 = [('A','AB'), ('B','CA'), ('CA','A'),('ABC','C')]
@@ -48,5 +43,3 @@ class PCPM(PCP):
       index_solution_pcp.append(c+1)
     index_solution_pcp.append(len(self))
     return index_solution_pcp
-
-
